import datetime

from django.contrib.auth.decorators import login_required
from django.http import JsonResponse
from django.utils import timezone

from web.api_views.daily_planning import get_workers_for_daily_planning, get_availabilities
from ..models import Worker


@login_required
def specializations(request):
    workers = Worker.objects.filter(specialization__isnull=False).values_list('specialization').distinct()
    return JsonResponse({
        "specializations": [x[0] for x in workers]
    })


@login_required
def units(request):
    workers = Worker.objects.filter(unit__isnull=False).values_list('unit').distinct()
    return JsonResponse({
        "units": [x[0] for x in workers]
    })


@login_required
def workers_for_daily_planning(request):
    workers = get_workers_for_daily_planning(request)
    workers_list_for_json = []
    for worker in workers:
        worker_dict_for_json = {
            'id': worker.id,
            'title': u"{} ({})".format(unicode(worker), worker.get_role_display()[:1].upper()),
            'role': worker.get_role_display()
        }
        workers_list_for_json.append(worker_dict_for_json)
    return JsonResponse(workers_list_for_json, safe=False)


@login_required
def availabilities(request):
    result = []
    min_date = request.GET.get("start_date")
    max_date = request.GET.get("end_date")

    workers = get_workers_for_daily_planning(request)

    min_date = datetime.datetime.strptime(min_date, "%Y-%m-%d").replace(tzinfo=timezone.now().tzinfo)
    max_date = datetime.datetime.strptime(max_date, "%Y-%m-%d").replace(tzinfo=timezone.now().tzinfo)

    while min_date <= max_date:
        str_date = min_date.strftime('%Y-%m-%d')
        date_result = {"date": str_date, "workers": []}
        for worker in workers:
            if len(get_availabilities(worker, str_date)) > 0:
                date_result["workers"].append({
                    "worker_id": worker.id,
                    "initials": worker.initials(),
                })
        result.append(date_result)
        min_date += datetime.timedelta(days=1)

    return JsonResponse({
        "availabilities": result,
    })
