# coding=utf-8
from django.db import models

from constants import SEX_CHOICES, COUNTRY_OTHER_ID
from web.models import Country, Visit, Appointment
from . import Language


class Subject(models.Model):
    class Meta:
        app_label = 'web'

    sex = models.CharField(max_length=1,
                           choices=SEX_CHOICES,
                           verbose_name='Sex'
                           )

    first_name = models.CharField(max_length=50,
                                  verbose_name='First name'
                                  )

    social_security_number = models.CharField(max_length=50,
                                              verbose_name='Social security_number',
                                              blank=True,
                                              )

    last_name = models.CharField(max_length=50,
                                 verbose_name='Last name'
                                 )

    languages = models.ManyToManyField(Language,
                                       blank=True,
                                       verbose_name='Known languages'
                                       )

    default_written_communication_language = models.ForeignKey(Language,
                                                               null=True,
                                                               blank=True,
                                                               related_name="subjects_written_communication",
                                                               verbose_name='Default language for document generation'
                                                               )
    phone_number = models.CharField(max_length=20,
                                    null=True,
                                    blank=True,
                                    verbose_name='Phone number'
                                    )

    phone_number_2 = models.CharField(max_length=20,
                                      null=True,
                                      blank=True,
                                      verbose_name='Phone number 2'
                                      )

    phone_number_3 = models.CharField(max_length=20,
                                      null=True,
                                      blank=True,
                                      verbose_name='Phone number 3'
                                      )

    email = models.EmailField(
        null=True,
        blank=True,
        verbose_name='E-mail'
    )

    date_born = models.DateField(
        null=True,
        blank=True,
        verbose_name='Date of birth (YYYY-MM-DD)'
    )

    address = models.CharField(max_length=255,
                               blank=True,
                               verbose_name='Address'
                               )

    postal_code = models.CharField(max_length=7,
                                   blank=True,
                                   verbose_name='Postal code'
                                   )

    city = models.CharField(max_length=50,
                            blank=True,
                            verbose_name='City'
                            )

    country = models.ForeignKey(Country,
                                null=False,
                                blank=False,
                                default=COUNTRY_OTHER_ID,
                                verbose_name='Country'
                                )

    dead = models.BooleanField(
        verbose_name='Deceased',
        default=False,
        editable=True
    )

    def mark_as_dead(self):
        self.dead = True
        self.finish_all_visits()
        self.finish_all_appointments()

    def finish_all_visits(self):
        visits = Visit.objects.filter(subject__subject=self, is_finished=False)
        for visit in visits:
            visit.is_finished = True
            visit.save()

    def finish_all_appointments(self):
        appointments = Appointment.objects.filter(visit__subject__subject=self,
                                                  status=Appointment.APPOINTMENT_STATUS_SCHEDULED)
        for appointment in appointments:
            appointment.status = Appointment.APPOINTMENT_STATUS_CANCELLED
            appointment.save()

    def __str__(self):
        return "%s %s" % (self.first_name, self.last_name)

    def __unicode__(self):
        return "%s %s" % (self.first_name, self.last_name)
