import datetime

from django.contrib.auth.models import User, AnonymousUser
from django.test import Client, TestCase

from web.models import Holiday, Worker
from web.tests.functions import create_worker
from web.views.notifications import get_today_midnight_date


class WorkerModelTests(TestCase):
    def test_disable(self):
        client = Client()
        username = 'piotr'
        password = 'top_secret'
        user = User.objects.create_user(username=username, email='jacob@bla', password=password)
        worker = create_worker(user)

        disable_status = worker.disable()
        self.assertTrue(disable_status)

        success = client.login(username=username, password=password)
        self.assertFalse(success)
        self.assertFalse(user.is_active)
        self.assertFalse(worker.is_active())

    def test_disable_invalid(self):
        worker = create_worker()
        disable_status = worker.disable()
        self.assertFalse(disable_status)

    def test_is_active_for_invalid(self):
        worker = create_worker()
        self.assertFalse(worker.is_active())

    def test_get_by_user_for_None(self):
        worker = Worker.get_by_user(None)
        self.assertIsNone(worker)

    def test_get_by_user_for_Worker(self):
        worker = create_worker()
        worker_2 = Worker.get_by_user(worker)
        self.assertEqual(worker, worker_2)

    def test_get_by_user_for_invalid(self):
        try:
            Worker.get_by_user("invalid object")
            self.fail("Exception expected")
        except TypeError:
            pass

    def test_is_on_leave(self):
        worker = create_worker()
        self.assertFalse(worker.is_on_leave())
        Holiday(person=worker,
                datetime_start=get_today_midnight_date() + datetime.timedelta(days=-2),
                datetime_end=get_today_midnight_date() + datetime.timedelta(days=2)).save()

        self.assertTrue(worker.is_on_leave())

    def test_get_by_user_for_anonymous(self):
        self.assertIsNone(Worker.get_by_user(AnonymousUser()))
