import logging

from django.urls import reverse

from web.tests.functions import create_language, create_location, create_availability
from web.forms import WorkerAddForm
from web.tests import create_worker
from web.models import Worker
from .. import LoggedInTestCase

logger = logging.getLogger(__name__)


class DoctorViewTests(LoggedInTestCase):
    def test_render_workers_list_request(self):
        create_worker()

        response = self.client.get(reverse('web.views.doctors'))
        self.assertEqual(response.status_code, 200)

    def test_render_add_worker_request(self):
        create_worker()

        response = self.client.get(reverse('web.views.doctor_add'))
        self.assertEqual(response.status_code, 200)

    def test_render_worker_added_request(self):

        language = create_language()
        location = create_location()
        count = Worker.objects.all().count()

        form = WorkerAddForm()
        form_data = {}
        for key, value in form.initial.items():
            if value is not None:
                form_data[key] = value
        form_data["first_name"] = "John"
        form_data["last_name"] = "Doe"
        form_data["phone_number"] = "0123456789"
        form_data["unit"] = "TEST DEPARTMENT"
        form_data["email"] = "john.doe@unknown.domain.com"
        form_data["role"] = Worker.ROLE_CHOICES_DOCTOR
        form_data["specialization"] = "tester"
        form_data["languages"] = [language.id]
        form_data["locations"] = [location.id]

        response = self.client.post(reverse('web.views.doctor_add'), data=form_data)

        self.assertEqual(response.status_code, 302)

        new_count = Worker.objects.all().count()
        self.assertEqual(count + 1, new_count)

    def test_render_edit_worker_request(self):
        worker = create_worker()

        response = self.client.get(reverse('web.views.doctor_edit', args=[worker.id]))
        self.assertEqual(response.status_code, 200)

    def test_render_add_availability_request(self):
        worker = create_worker()

        response = self.client.get(reverse('views.doctor.doctor_availability_add', args=[worker.id]))
        self.assertEqual(response.status_code, 200)

    def test_render_edit_availability_request(self):
        worker = create_worker()
        availability = create_availability(worker)

        response = self.client.get(reverse('web.views.doctor_availability_edit', args=[availability.id]))
        self.assertEqual(response.status_code, 200)

    def test_render_add_holiday_request(self):
        worker = create_worker()

        response = self.client.get(reverse('views.doctor.doctor_holiday_add', args=[worker.id]))
        self.assertEqual(response.status_code, 200)
